==> shellcheck-0.11.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ShellCheck
version:              0.11.0
visibility:           public
id:                   ShellCheck-0.11.0-BiJACcz22ym6zGSe5Rl5eU
key:                  ShellCheck-0.11.0-BiJACcz22ym6zGSe5Rl5eU
license:              GPL-3.0-only
maintainer:           vidar@vidarholen.net
author:               Vidar Holen
homepage:             https://www.shellcheck.net/
synopsis:             Shell script analysis tool
description:
    The goals of ShellCheck are:

    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.

    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.

    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.

category:             Static Analysis
abi:                  b7fe7627dbfb3f676e6d8d0c901f37e7
exposed:              True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.CFG
    ShellCheck.CFGAnalysis ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ControlFlow
    ShellCheck.Checks.Custom ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Debug ShellCheck.Fixer
    ShellCheck.Formatter.CheckStyle ShellCheck.Formatter.Diff
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.JSON1
    ShellCheck.Formatter.Quiet ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Prelude
    ShellCheck.Regex

hidden-modules:       Paths_ShellCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ShellCheck-0.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ShellCheck-0.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ShellCheck-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/shellcheck
hs-libraries:         HSShellCheck-0.11.0-BiJACcz22ym6zGSe5Rl5eU
depends:
    Diff-0.4.1-KLr9PfX1xcQ7rTrhHR462U
    QuickCheck-2.14.3-5RH984QQwd07L7POXdEIyh
    aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 fgl-5.8.3.0-95SEn23bG7xEGfKGhMMHq3
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.16.1 process-1.6.18.0
    regex-tdfa-1.3.2.4-DzgOWHlgf3T5HZBC9uVz6f transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html:         /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> shellcheck-0.11.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ShellCheck
version:              0.11.0
visibility:           public
id:                   ShellCheck-0.11.0-EKGaYxcMtb8G3o36WEo1cH
key:                  ShellCheck-0.11.0-EKGaYxcMtb8G3o36WEo1cH
license:              GPL-3.0-only
maintainer:           vidar@vidarholen.net
author:               Vidar Holen
homepage:             https://www.shellcheck.net/
synopsis:             Shell script analysis tool
description:
    The goals of ShellCheck are:

    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.

    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.

    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.

category:             Static Analysis
abi:                  cc4070bf8041bfe81d40142098413586
exposed:              True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.CFG
    ShellCheck.CFGAnalysis ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ControlFlow
    ShellCheck.Checks.Custom ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Debug ShellCheck.Fixer
    ShellCheck.Formatter.CheckStyle ShellCheck.Formatter.Diff
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.JSON1
    ShellCheck.Formatter.Quiet ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Prelude
    ShellCheck.Regex

hidden-modules:       Paths_ShellCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ShellCheck-0.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ShellCheck-0.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ShellCheck-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/shellcheck
hs-libraries:         HSShellCheck-0.11.0-EKGaYxcMtb8G3o36WEo1cH
depends:
    Diff-0.4.1-Jwj4OLAfw0yEVliC3dyBin
    QuickCheck-2.14.3-KXTisc688NGHRnxG3vFYz5
    aeson-2.1.2.1-8kv8xeVfmZaCzdZG9aqfKb array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 fgl-5.8.3.0-E9USikl9DOxDRAv2Ip68xD
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.16.1 process-1.6.18.0
    regex-tdfa-1.3.2.4-4v18KqMgCkG8zIhzTwZAyQ transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html:         /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
